@@ -1,13 +1,37 @@
-#[doc = "Reader of register POFCON"]
-pub type R = crate::R<u32, super::POFCON>;
-#[doc = "Writer for register POFCON"]
-pub type W = crate::W<u32, super::POFCON>;
-#[doc = "Register POFCON `reset()`'s with value 0"]
-impl crate::ResetValue for super::POFCON {
-    type Type = u32;
+#[doc = "Register `POFCON` reader"]
+pub struct R(crate::R<POFCON_SPEC>);
+impl core::ops::Deref for R {
+    type Target = crate::R<POFCON_SPEC>;
     #[inline(always)]
-    fn reset_value() -> Self::Type {
-        0
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+impl From<crate::R<POFCON_SPEC>> for R {
+    #[inline(always)]
+    fn from(reader: crate::R<POFCON_SPEC>) -> Self {
+        R(reader)
+    }
+}
+#[doc = "Register `POFCON` writer"]
+pub struct W(crate::W<POFCON_SPEC>);
+impl core::ops::Deref for W {
+    type Target = crate::W<POFCON_SPEC>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+impl core::ops::DerefMut for W {
+    #[inline(always)]
+    fn deref_mut(&mut self) -> &mut Self::Target {
+        &mut self.0
+    }
+}
+impl From<crate::W<POFCON_SPEC>> for W {
+    #[inline(always)]
+    fn from(writer: crate::W<POFCON_SPEC>) -> Self {
+        W(writer)
     }
 }
 #[doc = "Enable or disable power failure warning\n\nValue on reset: 0"]
@@ -24,9 +48,13 @@ impl From<POF_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `POF`"]
-pub type POF_R = crate::R<bool, POF_A>;
+#[doc = "Field `POF` reader - Enable or disable power failure warning"]
+pub struct POF_R(crate::FieldReader<bool, POF_A>);
 impl POF_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        POF_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> POF_A {
@@ -38,15 +66,22 @@ impl POF_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == POF_A::DISABLED
+        **self == POF_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == POF_A::ENABLED
+        **self == POF_A::ENABLED
     }
 }
-#[doc = "Write proxy for field `POF`"]
+impl core::ops::Deref for POF_R {
+    type Target = crate::FieldReader<bool, POF_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `POF` writer - Enable or disable power failure warning"]
 pub struct POF_W<'a> {
     w: &'a mut W,
 }
@@ -54,9 +89,7 @@ impl<'a> POF_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: POF_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Disable"]
     #[inline(always)]
@@ -81,7 +114,7 @@ impl<'a> POF_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | ((value as u32) & 0x01);
+        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
         self.w
     }
 }
@@ -120,91 +153,101 @@ impl From<THRESHOLD_A> for u8 {
         variant as _
     }
 }
-#[doc = "Reader of field `THRESHOLD`"]
-pub type THRESHOLD_R = crate::R<u8, THRESHOLD_A>;
+#[doc = "Field `THRESHOLD` reader - Power-fail comparator threshold setting. This setting applies both for normal voltage mode (supply connected to both VDD and VDDH) and high voltage mode (supply connected to VDDH only). Values 0-3 set threshold below 1.7 V and should not be used as brown out detection will be activated before power failure warning on such low voltages."]
+pub struct THRESHOLD_R(crate::FieldReader<u8, THRESHOLD_A>);
 impl THRESHOLD_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: u8) -> Self {
+        THRESHOLD_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
-    pub fn variant(&self) -> crate::Variant<u8, THRESHOLD_A> {
-        use crate::Variant::*;
+    pub fn variant(&self) -> Option<THRESHOLD_A> {
         match self.bits {
-            4 => Val(THRESHOLD_A::V17),
-            5 => Val(THRESHOLD_A::V18),
-            6 => Val(THRESHOLD_A::V19),
-            7 => Val(THRESHOLD_A::V20),
-            8 => Val(THRESHOLD_A::V21),
-            9 => Val(THRESHOLD_A::V22),
-            10 => Val(THRESHOLD_A::V23),
-            11 => Val(THRESHOLD_A::V24),
-            12 => Val(THRESHOLD_A::V25),
-            13 => Val(THRESHOLD_A::V26),
-            14 => Val(THRESHOLD_A::V27),
-            15 => Val(THRESHOLD_A::V28),
-            i => Res(i),
+            4 => Some(THRESHOLD_A::V17),
+            5 => Some(THRESHOLD_A::V18),
+            6 => Some(THRESHOLD_A::V19),
+            7 => Some(THRESHOLD_A::V20),
+            8 => Some(THRESHOLD_A::V21),
+            9 => Some(THRESHOLD_A::V22),
+            10 => Some(THRESHOLD_A::V23),
+            11 => Some(THRESHOLD_A::V24),
+            12 => Some(THRESHOLD_A::V25),
+            13 => Some(THRESHOLD_A::V26),
+            14 => Some(THRESHOLD_A::V27),
+            15 => Some(THRESHOLD_A::V28),
+            _ => None,
         }
     }
     #[doc = "Checks if the value of the field is `V17`"]
     #[inline(always)]
     pub fn is_v17(&self) -> bool {
-        *self == THRESHOLD_A::V17
+        **self == THRESHOLD_A::V17
     }
     #[doc = "Checks if the value of the field is `V18`"]
     #[inline(always)]
     pub fn is_v18(&self) -> bool {
-        *self == THRESHOLD_A::V18
+        **self == THRESHOLD_A::V18
     }
     #[doc = "Checks if the value of the field is `V19`"]
     #[inline(always)]
     pub fn is_v19(&self) -> bool {
-        *self == THRESHOLD_A::V19
+        **self == THRESHOLD_A::V19
     }
     #[doc = "Checks if the value of the field is `V20`"]
     #[inline(always)]
     pub fn is_v20(&self) -> bool {
-        *self == THRESHOLD_A::V20
+        **self == THRESHOLD_A::V20
     }
     #[doc = "Checks if the value of the field is `V21`"]
     #[inline(always)]
     pub fn is_v21(&self) -> bool {
-        *self == THRESHOLD_A::V21
+        **self == THRESHOLD_A::V21
     }
     #[doc = "Checks if the value of the field is `V22`"]
     #[inline(always)]
     pub fn is_v22(&self) -> bool {
-        *self == THRESHOLD_A::V22
+        **self == THRESHOLD_A::V22
     }
     #[doc = "Checks if the value of the field is `V23`"]
     #[inline(always)]
     pub fn is_v23(&self) -> bool {
-        *self == THRESHOLD_A::V23
+        **self == THRESHOLD_A::V23
     }
     #[doc = "Checks if the value of the field is `V24`"]
     #[inline(always)]
     pub fn is_v24(&self) -> bool {
-        *self == THRESHOLD_A::V24
+        **self == THRESHOLD_A::V24
     }
     #[doc = "Checks if the value of the field is `V25`"]
     #[inline(always)]
     pub fn is_v25(&self) -> bool {
-        *self == THRESHOLD_A::V25
+        **self == THRESHOLD_A::V25
     }
     #[doc = "Checks if the value of the field is `V26`"]
     #[inline(always)]
     pub fn is_v26(&self) -> bool {
-        *self == THRESHOLD_A::V26
+        **self == THRESHOLD_A::V26
     }
     #[doc = "Checks if the value of the field is `V27`"]
     #[inline(always)]
     pub fn is_v27(&self) -> bool {
-        *self == THRESHOLD_A::V27
+        **self == THRESHOLD_A::V27
     }
     #[doc = "Checks if the value of the field is `V28`"]
     #[inline(always)]
     pub fn is_v28(&self) -> bool {
-        *self == THRESHOLD_A::V28
+        **self == THRESHOLD_A::V28
     }
 }
-#[doc = "Write proxy for field `THRESHOLD`"]
+impl core::ops::Deref for THRESHOLD_R {
+    type Target = crate::FieldReader<u8, THRESHOLD_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `THRESHOLD` writer - Power-fail comparator threshold setting. This setting applies both for normal voltage mode (supply connected to both VDD and VDDH) and high voltage mode (supply connected to VDDH only). Values 0-3 set threshold below 1.7 V and should not be used as brown out detection will be activated before power failure warning on such low voltages."]
 pub struct THRESHOLD_W<'a> {
     w: &'a mut W,
 }
@@ -277,7 +320,7 @@ impl<'a> THRESHOLD_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x0f << 1)) | (((value as u32) & 0x0f) << 1);
+        self.w.bits = (self.w.bits & !(0x0f << 1)) | ((value as u32 & 0x0f) << 1);
         self.w
     }
 }
@@ -324,9 +367,13 @@ impl From<THRESHOLDVDDH_A> for u8 {
         variant as _
     }
 }
-#[doc = "Reader of field `THRESHOLDVDDH`"]
-pub type THRESHOLDVDDH_R = crate::R<u8, THRESHOLDVDDH_A>;
+#[doc = "Field `THRESHOLDVDDH` reader - Power-fail comparator threshold setting for high voltage mode (supply connected to VDDH only). This setting does not apply for normal voltage mode (supply connected to both VDD and VDDH)."]
+pub struct THRESHOLDVDDH_R(crate::FieldReader<u8, THRESHOLDVDDH_A>);
 impl THRESHOLDVDDH_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: u8) -> Self {
+        THRESHOLDVDDH_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> THRESHOLDVDDH_A {
@@ -353,85 +400,92 @@ impl THRESHOLDVDDH_R {
     #[doc = "Checks if the value of the field is `V27`"]
     #[inline(always)]
     pub fn is_v27(&self) -> bool {
-        *self == THRESHOLDVDDH_A::V27
+        **self == THRESHOLDVDDH_A::V27
     }
     #[doc = "Checks if the value of the field is `V28`"]
     #[inline(always)]
     pub fn is_v28(&self) -> bool {
-        *self == THRESHOLDVDDH_A::V28
+        **self == THRESHOLDVDDH_A::V28
     }
     #[doc = "Checks if the value of the field is `V29`"]
     #[inline(always)]
     pub fn is_v29(&self) -> bool {
-        *self == THRESHOLDVDDH_A::V29
+        **self == THRESHOLDVDDH_A::V29
     }
     #[doc = "Checks if the value of the field is `V30`"]
     #[inline(always)]
     pub fn is_v30(&self) -> bool {
-        *self == THRESHOLDVDDH_A::V30
+        **self == THRESHOLDVDDH_A::V30
     }
     #[doc = "Checks if the value of the field is `V31`"]
     #[inline(always)]
     pub fn is_v31(&self) -> bool {
-        *self == THRESHOLDVDDH_A::V31
+        **self == THRESHOLDVDDH_A::V31
     }
     #[doc = "Checks if the value of the field is `V32`"]
     #[inline(always)]
     pub fn is_v32(&self) -> bool {
-        *self == THRESHOLDVDDH_A::V32
+        **self == THRESHOLDVDDH_A::V32
     }
     #[doc = "Checks if the value of the field is `V33`"]
     #[inline(always)]
     pub fn is_v33(&self) -> bool {
-        *self == THRESHOLDVDDH_A::V33
+        **self == THRESHOLDVDDH_A::V33
     }
     #[doc = "Checks if the value of the field is `V34`"]
     #[inline(always)]
     pub fn is_v34(&self) -> bool {
-        *self == THRESHOLDVDDH_A::V34
+        **self == THRESHOLDVDDH_A::V34
     }
     #[doc = "Checks if the value of the field is `V35`"]
     #[inline(always)]
     pub fn is_v35(&self) -> bool {
-        *self == THRESHOLDVDDH_A::V35
+        **self == THRESHOLDVDDH_A::V35
     }
     #[doc = "Checks if the value of the field is `V36`"]
     #[inline(always)]
     pub fn is_v36(&self) -> bool {
-        *self == THRESHOLDVDDH_A::V36
+        **self == THRESHOLDVDDH_A::V36
     }
     #[doc = "Checks if the value of the field is `V37`"]
     #[inline(always)]
     pub fn is_v37(&self) -> bool {
-        *self == THRESHOLDVDDH_A::V37
+        **self == THRESHOLDVDDH_A::V37
     }
     #[doc = "Checks if the value of the field is `V38`"]
     #[inline(always)]
     pub fn is_v38(&self) -> bool {
-        *self == THRESHOLDVDDH_A::V38
+        **self == THRESHOLDVDDH_A::V38
     }
     #[doc = "Checks if the value of the field is `V39`"]
     #[inline(always)]
     pub fn is_v39(&self) -> bool {
-        *self == THRESHOLDVDDH_A::V39
+        **self == THRESHOLDVDDH_A::V39
     }
     #[doc = "Checks if the value of the field is `V40`"]
     #[inline(always)]
     pub fn is_v40(&self) -> bool {
-        *self == THRESHOLDVDDH_A::V40
+        **self == THRESHOLDVDDH_A::V40
     }
     #[doc = "Checks if the value of the field is `V41`"]
     #[inline(always)]
     pub fn is_v41(&self) -> bool {
-        *self == THRESHOLDVDDH_A::V41
+        **self == THRESHOLDVDDH_A::V41
     }
     #[doc = "Checks if the value of the field is `V42`"]
     #[inline(always)]
     pub fn is_v42(&self) -> bool {
-        *self == THRESHOLDVDDH_A::V42
+        **self == THRESHOLDVDDH_A::V42
     }
 }
-#[doc = "Write proxy for field `THRESHOLDVDDH`"]
+impl core::ops::Deref for THRESHOLDVDDH_R {
+    type Target = crate::FieldReader<u8, THRESHOLDVDDH_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `THRESHOLDVDDH` writer - Power-fail comparator threshold setting for high voltage mode (supply connected to VDDH only). This setting does not apply for normal voltage mode (supply connected to both VDD and VDDH)."]
 pub struct THRESHOLDVDDH_W<'a> {
     w: &'a mut W,
 }
@@ -439,9 +493,7 @@ impl<'a> THRESHOLDVDDH_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: THRESHOLDVDDH_A) -> &'a mut W {
-        {
-            self.bits(variant.into())
-        }
+        self.bits(variant.into())
     }
     #[doc = "Set threshold to 2.7 V"]
     #[inline(always)]
@@ -526,7 +578,7 @@ impl<'a> THRESHOLDVDDH_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x0f << 8)) | (((value as u32) & 0x0f) << 8);
+        self.w.bits = (self.w.bits & !(0x0f << 8)) | ((value as u32 & 0x0f) << 8);
         self.w
     }
 }
@@ -563,4 +615,30 @@ impl W {
     pub fn thresholdvddh(&mut self) -> THRESHOLDVDDH_W {
         THRESHOLDVDDH_W { w: self }
     }
+    #[doc = "Writes raw bits to the register."]
+    #[inline(always)]
+    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
+        self.0.bits(bits);
+        self
+    }
+}
+#[doc = "Power-fail comparator configuration\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [pofcon](index.html) module"]
+pub struct POFCON_SPEC;
+impl crate::RegisterSpec for POFCON_SPEC {
+    type Ux = u32;
+}
+#[doc = "`read()` method returns [pofcon::R](R) reader structure"]
+impl crate::Readable for POFCON_SPEC {
+    type Reader = R;
+}
+#[doc = "`write(|w| ..)` method takes [pofcon::W](W) writer structure"]
+impl crate::Writable for POFCON_SPEC {
+    type Writer = W;
+}
+#[doc = "`reset()` method sets POFCON to value 0"]
+impl crate::Resettable for POFCON_SPEC {
+    #[inline(always)]
+    fn reset_value() -> Self::Ux {
+        0
+    }
 }
