@@ -1,13 +1,37 @@
-#[doc = "Reader of register CTEINLINECONF"]
-pub type R = crate::R<u32, super::CTEINLINECONF>;
-#[doc = "Writer for register CTEINLINECONF"]
-pub type W = crate::W<u32, super::CTEINLINECONF>;
-#[doc = "Register CTEINLINECONF `reset()`'s with value 0x2800"]
-impl crate::ResetValue for super::CTEINLINECONF {
-    type Type = u32;
+#[doc = "Register `CTEINLINECONF` reader"]
+pub struct R(crate::R<CTEINLINECONF_SPEC>);
+impl core::ops::Deref for R {
+    type Target = crate::R<CTEINLINECONF_SPEC>;
     #[inline(always)]
-    fn reset_value() -> Self::Type {
-        0x2800
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+impl From<crate::R<CTEINLINECONF_SPEC>> for R {
+    #[inline(always)]
+    fn from(reader: crate::R<CTEINLINECONF_SPEC>) -> Self {
+        R(reader)
+    }
+}
+#[doc = "Register `CTEINLINECONF` writer"]
+pub struct W(crate::W<CTEINLINECONF_SPEC>);
+impl core::ops::Deref for W {
+    type Target = crate::W<CTEINLINECONF_SPEC>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+impl core::ops::DerefMut for W {
+    #[inline(always)]
+    fn deref_mut(&mut self) -> &mut Self::Target {
+        &mut self.0
+    }
+}
+impl From<crate::W<CTEINLINECONF_SPEC>> for W {
+    #[inline(always)]
+    fn from(writer: crate::W<CTEINLINECONF_SPEC>) -> Self {
+        W(writer)
     }
 }
 #[doc = "Enable parsing of CTEInfo from received packet in BLE modes\n\nValue on reset: 0"]
@@ -24,9 +48,13 @@ impl From<CTEINLINECTRLEN_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `CTEINLINECTRLEN`"]
-pub type CTEINLINECTRLEN_R = crate::R<bool, CTEINLINECTRLEN_A>;
+#[doc = "Field `CTEINLINECTRLEN` reader - Enable parsing of CTEInfo from received packet in BLE modes"]
+pub struct CTEINLINECTRLEN_R(crate::FieldReader<bool, CTEINLINECTRLEN_A>);
 impl CTEINLINECTRLEN_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        CTEINLINECTRLEN_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> CTEINLINECTRLEN_A {
@@ -38,15 +66,22 @@ impl CTEINLINECTRLEN_R {
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == CTEINLINECTRLEN_A::ENABLED
+        **self == CTEINLINECTRLEN_A::ENABLED
     }
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == CTEINLINECTRLEN_A::DISABLED
+        **self == CTEINLINECTRLEN_A::DISABLED
     }
 }
-#[doc = "Write proxy for field `CTEINLINECTRLEN`"]
+impl core::ops::Deref for CTEINLINECTRLEN_R {
+    type Target = crate::FieldReader<bool, CTEINLINECTRLEN_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `CTEINLINECTRLEN` writer - Enable parsing of CTEInfo from received packet in BLE modes"]
 pub struct CTEINLINECTRLEN_W<'a> {
     w: &'a mut W,
 }
@@ -54,9 +89,7 @@ impl<'a> CTEINLINECTRLEN_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: CTEINLINECTRLEN_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Parsing of CTEInfo is enabled"]
     #[inline(always)]
@@ -81,7 +114,7 @@ impl<'a> CTEINLINECTRLEN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | ((value as u32) & 0x01);
+        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
         self.w
     }
 }
@@ -99,9 +132,13 @@ impl From<CTEINFOINS1_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `CTEINFOINS1`"]
-pub type CTEINFOINS1_R = crate::R<bool, CTEINFOINS1_A>;
+#[doc = "Field `CTEINFOINS1` reader - CTEInfo is S1 byte or not"]
+pub struct CTEINFOINS1_R(crate::FieldReader<bool, CTEINFOINS1_A>);
 impl CTEINFOINS1_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        CTEINFOINS1_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> CTEINFOINS1_A {
@@ -113,15 +150,22 @@ impl CTEINFOINS1_R {
     #[doc = "Checks if the value of the field is `INS1`"]
     #[inline(always)]
     pub fn is_in_s1(&self) -> bool {
-        *self == CTEINFOINS1_A::INS1
+        **self == CTEINFOINS1_A::INS1
     }
     #[doc = "Checks if the value of the field is `NOTINS1`"]
     #[inline(always)]
     pub fn is_not_in_s1(&self) -> bool {
-        *self == CTEINFOINS1_A::NOTINS1
+        **self == CTEINFOINS1_A::NOTINS1
     }
 }
-#[doc = "Write proxy for field `CTEINFOINS1`"]
+impl core::ops::Deref for CTEINFOINS1_R {
+    type Target = crate::FieldReader<bool, CTEINFOINS1_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `CTEINFOINS1` writer - CTEInfo is S1 byte or not"]
 pub struct CTEINFOINS1_W<'a> {
     w: &'a mut W,
 }
@@ -129,9 +173,7 @@ impl<'a> CTEINFOINS1_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: CTEINFOINS1_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "CTEInfo is in S1 byte (data PDU)"]
     #[inline(always)]
@@ -156,7 +198,7 @@ impl<'a> CTEINFOINS1_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | (((value as u32) & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
         self.w
     }
 }
@@ -174,9 +216,13 @@ impl From<CTEERRORHANDLING_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `CTEERRORHANDLING`"]
-pub type CTEERRORHANDLING_R = crate::R<bool, CTEERRORHANDLING_A>;
+#[doc = "Field `CTEERRORHANDLING` reader - Sampling/switching if CRC is not OK"]
+pub struct CTEERRORHANDLING_R(crate::FieldReader<bool, CTEERRORHANDLING_A>);
 impl CTEERRORHANDLING_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        CTEERRORHANDLING_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> CTEERRORHANDLING_A {
@@ -188,15 +234,22 @@ impl CTEERRORHANDLING_R {
     #[doc = "Checks if the value of the field is `YES`"]
     #[inline(always)]
     pub fn is_yes(&self) -> bool {
-        *self == CTEERRORHANDLING_A::YES
+        **self == CTEERRORHANDLING_A::YES
     }
     #[doc = "Checks if the value of the field is `NO`"]
     #[inline(always)]
     pub fn is_no(&self) -> bool {
-        *self == CTEERRORHANDLING_A::NO
+        **self == CTEERRORHANDLING_A::NO
     }
 }
-#[doc = "Write proxy for field `CTEERRORHANDLING`"]
+impl core::ops::Deref for CTEERRORHANDLING_R {
+    type Target = crate::FieldReader<bool, CTEERRORHANDLING_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `CTEERRORHANDLING` writer - Sampling/switching if CRC is not OK"]
 pub struct CTEERRORHANDLING_W<'a> {
     w: &'a mut W,
 }
@@ -204,9 +257,7 @@ impl<'a> CTEERRORHANDLING_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: CTEERRORHANDLING_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Sampling and antenna switching also when CRC is not OK"]
     #[inline(always)]
@@ -231,7 +282,7 @@ impl<'a> CTEERRORHANDLING_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | (((value as u32) & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
         self.w
     }
 }
@@ -252,37 +303,47 @@ impl From<CTETIMEVALIDRANGE_A> for u8 {
         variant as _
     }
 }
-#[doc = "Reader of field `CTETIMEVALIDRANGE`"]
-pub type CTETIMEVALIDRANGE_R = crate::R<u8, CTETIMEVALIDRANGE_A>;
+#[doc = "Field `CTETIMEVALIDRANGE` reader - Max range of CTETime"]
+pub struct CTETIMEVALIDRANGE_R(crate::FieldReader<u8, CTETIMEVALIDRANGE_A>);
 impl CTETIMEVALIDRANGE_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: u8) -> Self {
+        CTETIMEVALIDRANGE_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
-    pub fn variant(&self) -> crate::Variant<u8, CTETIMEVALIDRANGE_A> {
-        use crate::Variant::*;
+    pub fn variant(&self) -> Option<CTETIMEVALIDRANGE_A> {
         match self.bits {
-            0 => Val(CTETIMEVALIDRANGE_A::_20),
-            1 => Val(CTETIMEVALIDRANGE_A::_31),
-            2 => Val(CTETIMEVALIDRANGE_A::_63),
-            i => Res(i),
+            0 => Some(CTETIMEVALIDRANGE_A::_20),
+            1 => Some(CTETIMEVALIDRANGE_A::_31),
+            2 => Some(CTETIMEVALIDRANGE_A::_63),
+            _ => None,
         }
     }
     #[doc = "Checks if the value of the field is `_20`"]
     #[inline(always)]
     pub fn is_20(&self) -> bool {
-        *self == CTETIMEVALIDRANGE_A::_20
+        **self == CTETIMEVALIDRANGE_A::_20
     }
     #[doc = "Checks if the value of the field is `_31`"]
     #[inline(always)]
     pub fn is_31(&self) -> bool {
-        *self == CTETIMEVALIDRANGE_A::_31
+        **self == CTETIMEVALIDRANGE_A::_31
     }
     #[doc = "Checks if the value of the field is `_63`"]
     #[inline(always)]
     pub fn is_63(&self) -> bool {
-        *self == CTETIMEVALIDRANGE_A::_63
+        **self == CTETIMEVALIDRANGE_A::_63
     }
 }
-#[doc = "Write proxy for field `CTETIMEVALIDRANGE`"]
+impl core::ops::Deref for CTETIMEVALIDRANGE_R {
+    type Target = crate::FieldReader<u8, CTETIMEVALIDRANGE_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `CTETIMEVALIDRANGE` writer - Max range of CTETime"]
 pub struct CTETIMEVALIDRANGE_W<'a> {
     w: &'a mut W,
 }
@@ -310,7 +371,7 @@ impl<'a> CTETIMEVALIDRANGE_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x03 << 6)) | (((value as u32) & 0x03) << 6);
+        self.w.bits = (self.w.bits & !(0x03 << 6)) | ((value as u32 & 0x03) << 6);
         self.w
     }
 }
@@ -337,55 +398,65 @@ impl From<CTEINLINERXMODE1US_A> for u8 {
         variant as _
     }
 }
-#[doc = "Reader of field `CTEINLINERXMODE1US`"]
-pub type CTEINLINERXMODE1US_R = crate::R<u8, CTEINLINERXMODE1US_A>;
+#[doc = "Field `CTEINLINERXMODE1US` reader - Spacing between samples for the samples in the SWITCHING period when CTEINLINEMODE is set."]
+pub struct CTEINLINERXMODE1US_R(crate::FieldReader<u8, CTEINLINERXMODE1US_A>);
 impl CTEINLINERXMODE1US_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: u8) -> Self {
+        CTEINLINERXMODE1US_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
-    pub fn variant(&self) -> crate::Variant<u8, CTEINLINERXMODE1US_A> {
-        use crate::Variant::*;
+    pub fn variant(&self) -> Option<CTEINLINERXMODE1US_A> {
         match self.bits {
-            1 => Val(CTEINLINERXMODE1US_A::_4US),
-            2 => Val(CTEINLINERXMODE1US_A::_2US),
-            3 => Val(CTEINLINERXMODE1US_A::_1US),
-            4 => Val(CTEINLINERXMODE1US_A::_500NS),
-            5 => Val(CTEINLINERXMODE1US_A::_250NS),
-            6 => Val(CTEINLINERXMODE1US_A::_125NS),
-            i => Res(i),
+            1 => Some(CTEINLINERXMODE1US_A::_4US),
+            2 => Some(CTEINLINERXMODE1US_A::_2US),
+            3 => Some(CTEINLINERXMODE1US_A::_1US),
+            4 => Some(CTEINLINERXMODE1US_A::_500NS),
+            5 => Some(CTEINLINERXMODE1US_A::_250NS),
+            6 => Some(CTEINLINERXMODE1US_A::_125NS),
+            _ => None,
         }
     }
     #[doc = "Checks if the value of the field is `_4US`"]
     #[inline(always)]
     pub fn is_4us(&self) -> bool {
-        *self == CTEINLINERXMODE1US_A::_4US
+        **self == CTEINLINERXMODE1US_A::_4US
     }
     #[doc = "Checks if the value of the field is `_2US`"]
     #[inline(always)]
     pub fn is_2us(&self) -> bool {
-        *self == CTEINLINERXMODE1US_A::_2US
+        **self == CTEINLINERXMODE1US_A::_2US
     }
     #[doc = "Checks if the value of the field is `_1US`"]
     #[inline(always)]
     pub fn is_1us(&self) -> bool {
-        *self == CTEINLINERXMODE1US_A::_1US
+        **self == CTEINLINERXMODE1US_A::_1US
     }
     #[doc = "Checks if the value of the field is `_500NS`"]
     #[inline(always)]
     pub fn is_500ns(&self) -> bool {
-        *self == CTEINLINERXMODE1US_A::_500NS
+        **self == CTEINLINERXMODE1US_A::_500NS
     }
     #[doc = "Checks if the value of the field is `_250NS`"]
     #[inline(always)]
     pub fn is_250ns(&self) -> bool {
-        *self == CTEINLINERXMODE1US_A::_250NS
+        **self == CTEINLINERXMODE1US_A::_250NS
     }
     #[doc = "Checks if the value of the field is `_125NS`"]
     #[inline(always)]
     pub fn is_125ns(&self) -> bool {
-        *self == CTEINLINERXMODE1US_A::_125NS
+        **self == CTEINLINERXMODE1US_A::_125NS
     }
 }
-#[doc = "Write proxy for field `CTEINLINERXMODE1US`"]
+impl core::ops::Deref for CTEINLINERXMODE1US_R {
+    type Target = crate::FieldReader<u8, CTEINLINERXMODE1US_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `CTEINLINERXMODE1US` writer - Spacing between samples for the samples in the SWITCHING period when CTEINLINEMODE is set."]
 pub struct CTEINLINERXMODE1US_W<'a> {
     w: &'a mut W,
 }
@@ -428,7 +499,7 @@ impl<'a> CTEINLINERXMODE1US_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x07 << 10)) | (((value as u32) & 0x07) << 10);
+        self.w.bits = (self.w.bits & !(0x07 << 10)) | ((value as u32 & 0x07) << 10);
         self.w
     }
 }
@@ -455,55 +526,65 @@ impl From<CTEINLINERXMODE2US_A> for u8 {
         variant as _
     }
 }
-#[doc = "Reader of field `CTEINLINERXMODE2US`"]
-pub type CTEINLINERXMODE2US_R = crate::R<u8, CTEINLINERXMODE2US_A>;
+#[doc = "Field `CTEINLINERXMODE2US` reader - Spacing between samples for the samples in the SWITCHING period when CTEINLINEMODE is set."]
+pub struct CTEINLINERXMODE2US_R(crate::FieldReader<u8, CTEINLINERXMODE2US_A>);
 impl CTEINLINERXMODE2US_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: u8) -> Self {
+        CTEINLINERXMODE2US_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
-    pub fn variant(&self) -> crate::Variant<u8, CTEINLINERXMODE2US_A> {
-        use crate::Variant::*;
+    pub fn variant(&self) -> Option<CTEINLINERXMODE2US_A> {
         match self.bits {
-            1 => Val(CTEINLINERXMODE2US_A::_4US),
-            2 => Val(CTEINLINERXMODE2US_A::_2US),
-            3 => Val(CTEINLINERXMODE2US_A::_1US),
-            4 => Val(CTEINLINERXMODE2US_A::_500NS),
-            5 => Val(CTEINLINERXMODE2US_A::_250NS),
-            6 => Val(CTEINLINERXMODE2US_A::_125NS),
-            i => Res(i),
+            1 => Some(CTEINLINERXMODE2US_A::_4US),
+            2 => Some(CTEINLINERXMODE2US_A::_2US),
+            3 => Some(CTEINLINERXMODE2US_A::_1US),
+            4 => Some(CTEINLINERXMODE2US_A::_500NS),
+            5 => Some(CTEINLINERXMODE2US_A::_250NS),
+            6 => Some(CTEINLINERXMODE2US_A::_125NS),
+            _ => None,
         }
     }
     #[doc = "Checks if the value of the field is `_4US`"]
     #[inline(always)]
     pub fn is_4us(&self) -> bool {
-        *self == CTEINLINERXMODE2US_A::_4US
+        **self == CTEINLINERXMODE2US_A::_4US
     }
     #[doc = "Checks if the value of the field is `_2US`"]
     #[inline(always)]
     pub fn is_2us(&self) -> bool {
-        *self == CTEINLINERXMODE2US_A::_2US
+        **self == CTEINLINERXMODE2US_A::_2US
     }
     #[doc = "Checks if the value of the field is `_1US`"]
     #[inline(always)]
     pub fn is_1us(&self) -> bool {
-        *self == CTEINLINERXMODE2US_A::_1US
+        **self == CTEINLINERXMODE2US_A::_1US
     }
     #[doc = "Checks if the value of the field is `_500NS`"]
     #[inline(always)]
     pub fn is_500ns(&self) -> bool {
-        *self == CTEINLINERXMODE2US_A::_500NS
+        **self == CTEINLINERXMODE2US_A::_500NS
     }
     #[doc = "Checks if the value of the field is `_250NS`"]
     #[inline(always)]
     pub fn is_250ns(&self) -> bool {
-        *self == CTEINLINERXMODE2US_A::_250NS
+        **self == CTEINLINERXMODE2US_A::_250NS
     }
     #[doc = "Checks if the value of the field is `_125NS`"]
     #[inline(always)]
     pub fn is_125ns(&self) -> bool {
-        *self == CTEINLINERXMODE2US_A::_125NS
+        **self == CTEINLINERXMODE2US_A::_125NS
     }
 }
-#[doc = "Write proxy for field `CTEINLINERXMODE2US`"]
+impl core::ops::Deref for CTEINLINERXMODE2US_R {
+    type Target = crate::FieldReader<u8, CTEINLINERXMODE2US_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `CTEINLINERXMODE2US` writer - Spacing between samples for the samples in the SWITCHING period when CTEINLINEMODE is set."]
 pub struct CTEINLINERXMODE2US_W<'a> {
     w: &'a mut W,
 }
@@ -546,13 +627,26 @@ impl<'a> CTEINLINERXMODE2US_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x07 << 13)) | (((value as u32) & 0x07) << 13);
+        self.w.bits = (self.w.bits & !(0x07 << 13)) | ((value as u32 & 0x07) << 13);
         self.w
     }
 }
-#[doc = "Reader of field `S0CONF`"]
-pub type S0CONF_R = crate::R<u8, u8>;
-#[doc = "Write proxy for field `S0CONF`"]
+#[doc = "Field `S0CONF` reader - S0 bit pattern to match"]
+pub struct S0CONF_R(crate::FieldReader<u8, u8>);
+impl S0CONF_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: u8) -> Self {
+        S0CONF_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for S0CONF_R {
+    type Target = crate::FieldReader<u8, u8>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `S0CONF` writer - S0 bit pattern to match"]
 pub struct S0CONF_W<'a> {
     w: &'a mut W,
 }
@@ -560,13 +654,26 @@ impl<'a> S0CONF_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0xff << 16)) | (((value as u32) & 0xff) << 16);
+        self.w.bits = (self.w.bits & !(0xff << 16)) | ((value as u32 & 0xff) << 16);
         self.w
     }
 }
-#[doc = "Reader of field `S0MASK`"]
-pub type S0MASK_R = crate::R<u8, u8>;
-#[doc = "Write proxy for field `S0MASK`"]
+#[doc = "Field `S0MASK` reader - S0 bit mask to set which bit to match"]
+pub struct S0MASK_R(crate::FieldReader<u8, u8>);
+impl S0MASK_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: u8) -> Self {
+        S0MASK_R(crate::FieldReader::new(bits))
+    }
+}
+impl core::ops::Deref for S0MASK_R {
+    type Target = crate::FieldReader<u8, u8>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `S0MASK` writer - S0 bit mask to set which bit to match"]
 pub struct S0MASK_W<'a> {
     w: &'a mut W,
 }
@@ -574,7 +681,7 @@ impl<'a> S0MASK_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub unsafe fn bits(self, value: u8) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0xff << 24)) | (((value as u32) & 0xff) << 24);
+        self.w.bits = (self.w.bits & !(0xff << 24)) | ((value as u32 & 0xff) << 24);
         self.w
     }
 }
@@ -661,4 +768,30 @@ impl W {
     pub fn s0mask(&mut self) -> S0MASK_W {
         S0MASK_W { w: self }
     }
+    #[doc = "Writes raw bits to the register."]
+    #[inline(always)]
+    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
+        self.0.bits(bits);
+        self
+    }
+}
+#[doc = "Configuration for CTE inline mode\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [cteinlineconf](index.html) module"]
+pub struct CTEINLINECONF_SPEC;
+impl crate::RegisterSpec for CTEINLINECONF_SPEC {
+    type Ux = u32;
+}
+#[doc = "`read()` method returns [cteinlineconf::R](R) reader structure"]
+impl crate::Readable for CTEINLINECONF_SPEC {
+    type Reader = R;
+}
+#[doc = "`write(|w| ..)` method takes [cteinlineconf::W](W) writer structure"]
+impl crate::Writable for CTEINLINECONF_SPEC {
+    type Writer = W;
+}
+#[doc = "`reset()` method sets CTEINLINECONF to value 0x2800"]
+impl crate::Resettable for CTEINLINECONF_SPEC {
+    #[inline(always)]
+    fn reset_value() -> Self::Ux {
+        0x2800
+    }
 }
