@@ -1,13 +1,37 @@
-#[doc = "Reader of register INTENSET"]
-pub type R = crate::R<u32, super::INTENSET>;
-#[doc = "Writer for register INTENSET"]
-pub type W = crate::W<u32, super::INTENSET>;
-#[doc = "Register INTENSET `reset()`'s with value 0"]
-impl crate::ResetValue for super::INTENSET {
-    type Type = u32;
+#[doc = "Register `INTENSET` reader"]
+pub struct R(crate::R<INTENSET_SPEC>);
+impl core::ops::Deref for R {
+    type Target = crate::R<INTENSET_SPEC>;
     #[inline(always)]
-    fn reset_value() -> Self::Type {
-        0
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+impl From<crate::R<INTENSET_SPEC>> for R {
+    #[inline(always)]
+    fn from(reader: crate::R<INTENSET_SPEC>) -> Self {
+        R(reader)
+    }
+}
+#[doc = "Register `INTENSET` writer"]
+pub struct W(crate::W<INTENSET_SPEC>);
+impl core::ops::Deref for W {
+    type Target = crate::W<INTENSET_SPEC>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+impl core::ops::DerefMut for W {
+    #[inline(always)]
+    fn deref_mut(&mut self) -> &mut Self::Target {
+        &mut self.0
+    }
+}
+impl From<crate::W<INTENSET_SPEC>> for W {
+    #[inline(always)]
+    fn from(writer: crate::W<INTENSET_SPEC>) -> Self {
+        W(writer)
     }
 }
 #[doc = "Write '1' to enable interrupt for event STOPPED\n\nValue on reset: 0"]
@@ -24,9 +48,13 @@ impl From<STOPPED_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `STOPPED`"]
-pub type STOPPED_R = crate::R<bool, STOPPED_A>;
+#[doc = "Field `STOPPED` reader - Write '1' to enable interrupt for event STOPPED"]
+pub struct STOPPED_R(crate::FieldReader<bool, STOPPED_A>);
 impl STOPPED_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        STOPPED_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> STOPPED_A {
@@ -38,12 +66,19 @@ impl STOPPED_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == STOPPED_A::DISABLED
+        **self == STOPPED_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == STOPPED_A::ENABLED
+        **self == STOPPED_A::ENABLED
+    }
+}
+impl core::ops::Deref for STOPPED_R {
+    type Target = crate::FieldReader<bool, STOPPED_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to enable interrupt for event STOPPED\n\nValue on reset: 0"]
@@ -58,7 +93,7 @@ impl From<STOPPED_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `STOPPED`"]
+#[doc = "Field `STOPPED` writer - Write '1' to enable interrupt for event STOPPED"]
 pub struct STOPPED_W<'a> {
     w: &'a mut W,
 }
@@ -66,9 +101,7 @@ impl<'a> STOPPED_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: STOPPED_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Enable"]
     #[inline(always)]
@@ -88,7 +121,7 @@ impl<'a> STOPPED_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | (((value as u32) & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
         self.w
     }
 }
@@ -106,9 +139,13 @@ impl From<RXDREADY_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `RXDREADY`"]
-pub type RXDREADY_R = crate::R<bool, RXDREADY_A>;
+#[doc = "Field `RXDREADY` reader - Write '1' to enable interrupt for event RXDREADY"]
+pub struct RXDREADY_R(crate::FieldReader<bool, RXDREADY_A>);
 impl RXDREADY_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        RXDREADY_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> RXDREADY_A {
@@ -120,12 +157,19 @@ impl RXDREADY_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == RXDREADY_A::DISABLED
+        **self == RXDREADY_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == RXDREADY_A::ENABLED
+        **self == RXDREADY_A::ENABLED
+    }
+}
+impl core::ops::Deref for RXDREADY_R {
+    type Target = crate::FieldReader<bool, RXDREADY_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to enable interrupt for event RXDREADY\n\nValue on reset: 0"]
@@ -140,7 +184,7 @@ impl From<RXDREADY_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `RXDREADY`"]
+#[doc = "Field `RXDREADY` writer - Write '1' to enable interrupt for event RXDREADY"]
 pub struct RXDREADY_W<'a> {
     w: &'a mut W,
 }
@@ -148,9 +192,7 @@ impl<'a> RXDREADY_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: RXDREADY_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Enable"]
     #[inline(always)]
@@ -170,7 +212,7 @@ impl<'a> RXDREADY_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | (((value as u32) & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
         self.w
     }
 }
@@ -188,9 +230,13 @@ impl From<TXDSENT_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `TXDSENT`"]
-pub type TXDSENT_R = crate::R<bool, TXDSENT_A>;
+#[doc = "Field `TXDSENT` reader - Write '1' to enable interrupt for event TXDSENT"]
+pub struct TXDSENT_R(crate::FieldReader<bool, TXDSENT_A>);
 impl TXDSENT_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        TXDSENT_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> TXDSENT_A {
@@ -202,12 +248,19 @@ impl TXDSENT_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == TXDSENT_A::DISABLED
+        **self == TXDSENT_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == TXDSENT_A::ENABLED
+        **self == TXDSENT_A::ENABLED
+    }
+}
+impl core::ops::Deref for TXDSENT_R {
+    type Target = crate::FieldReader<bool, TXDSENT_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to enable interrupt for event TXDSENT\n\nValue on reset: 0"]
@@ -222,7 +275,7 @@ impl From<TXDSENT_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `TXDSENT`"]
+#[doc = "Field `TXDSENT` writer - Write '1' to enable interrupt for event TXDSENT"]
 pub struct TXDSENT_W<'a> {
     w: &'a mut W,
 }
@@ -230,9 +283,7 @@ impl<'a> TXDSENT_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: TXDSENT_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Enable"]
     #[inline(always)]
@@ -252,7 +303,7 @@ impl<'a> TXDSENT_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | (((value as u32) & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
         self.w
     }
 }
@@ -270,9 +321,13 @@ impl From<ERROR_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `ERROR`"]
-pub type ERROR_R = crate::R<bool, ERROR_A>;
+#[doc = "Field `ERROR` reader - Write '1' to enable interrupt for event ERROR"]
+pub struct ERROR_R(crate::FieldReader<bool, ERROR_A>);
 impl ERROR_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        ERROR_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> ERROR_A {
@@ -284,12 +339,19 @@ impl ERROR_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == ERROR_A::DISABLED
+        **self == ERROR_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == ERROR_A::ENABLED
+        **self == ERROR_A::ENABLED
+    }
+}
+impl core::ops::Deref for ERROR_R {
+    type Target = crate::FieldReader<bool, ERROR_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to enable interrupt for event ERROR\n\nValue on reset: 0"]
@@ -304,7 +366,7 @@ impl From<ERROR_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `ERROR`"]
+#[doc = "Field `ERROR` writer - Write '1' to enable interrupt for event ERROR"]
 pub struct ERROR_W<'a> {
     w: &'a mut W,
 }
@@ -312,9 +374,7 @@ impl<'a> ERROR_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: ERROR_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Enable"]
     #[inline(always)]
@@ -334,7 +394,7 @@ impl<'a> ERROR_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 9)) | (((value as u32) & 0x01) << 9);
+        self.w.bits = (self.w.bits & !(0x01 << 9)) | ((value as u32 & 0x01) << 9);
         self.w
     }
 }
@@ -352,9 +412,13 @@ impl From<BB_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `BB`"]
-pub type BB_R = crate::R<bool, BB_A>;
+#[doc = "Field `BB` reader - Write '1' to enable interrupt for event BB"]
+pub struct BB_R(crate::FieldReader<bool, BB_A>);
 impl BB_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        BB_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> BB_A {
@@ -366,12 +430,19 @@ impl BB_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == BB_A::DISABLED
+        **self == BB_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == BB_A::ENABLED
+        **self == BB_A::ENABLED
+    }
+}
+impl core::ops::Deref for BB_R {
+    type Target = crate::FieldReader<bool, BB_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to enable interrupt for event BB\n\nValue on reset: 0"]
@@ -386,7 +457,7 @@ impl From<BB_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `BB`"]
+#[doc = "Field `BB` writer - Write '1' to enable interrupt for event BB"]
 pub struct BB_W<'a> {
     w: &'a mut W,
 }
@@ -394,9 +465,7 @@ impl<'a> BB_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: BB_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Enable"]
     #[inline(always)]
@@ -416,7 +485,7 @@ impl<'a> BB_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 14)) | (((value as u32) & 0x01) << 14);
+        self.w.bits = (self.w.bits & !(0x01 << 14)) | ((value as u32 & 0x01) << 14);
         self.w
     }
 }
@@ -434,9 +503,13 @@ impl From<SUSPENDED_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `SUSPENDED`"]
-pub type SUSPENDED_R = crate::R<bool, SUSPENDED_A>;
+#[doc = "Field `SUSPENDED` reader - Write '1' to enable interrupt for event SUSPENDED"]
+pub struct SUSPENDED_R(crate::FieldReader<bool, SUSPENDED_A>);
 impl SUSPENDED_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        SUSPENDED_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> SUSPENDED_A {
@@ -448,12 +521,19 @@ impl SUSPENDED_R {
     #[doc = "Checks if the value of the field is `DISABLED`"]
     #[inline(always)]
     pub fn is_disabled(&self) -> bool {
-        *self == SUSPENDED_A::DISABLED
+        **self == SUSPENDED_A::DISABLED
     }
     #[doc = "Checks if the value of the field is `ENABLED`"]
     #[inline(always)]
     pub fn is_enabled(&self) -> bool {
-        *self == SUSPENDED_A::ENABLED
+        **self == SUSPENDED_A::ENABLED
+    }
+}
+impl core::ops::Deref for SUSPENDED_R {
+    type Target = crate::FieldReader<bool, SUSPENDED_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
     }
 }
 #[doc = "Write '1' to enable interrupt for event SUSPENDED\n\nValue on reset: 0"]
@@ -468,7 +548,7 @@ impl From<SUSPENDED_AW> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Write proxy for field `SUSPENDED`"]
+#[doc = "Field `SUSPENDED` writer - Write '1' to enable interrupt for event SUSPENDED"]
 pub struct SUSPENDED_W<'a> {
     w: &'a mut W,
 }
@@ -476,9 +556,7 @@ impl<'a> SUSPENDED_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: SUSPENDED_AW) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Enable"]
     #[inline(always)]
@@ -498,7 +576,7 @@ impl<'a> SUSPENDED_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 18)) | (((value as u32) & 0x01) << 18);
+        self.w.bits = (self.w.bits & !(0x01 << 18)) | ((value as u32 & 0x01) << 18);
         self.w
     }
 }
@@ -565,4 +643,30 @@ impl W {
     pub fn suspended(&mut self) -> SUSPENDED_W {
         SUSPENDED_W { w: self }
     }
+    #[doc = "Writes raw bits to the register."]
+    #[inline(always)]
+    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
+        self.0.bits(bits);
+        self
+    }
+}
+#[doc = "Enable interrupt\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [intenset](index.html) module"]
+pub struct INTENSET_SPEC;
+impl crate::RegisterSpec for INTENSET_SPEC {
+    type Ux = u32;
+}
+#[doc = "`read()` method returns [intenset::R](R) reader structure"]
+impl crate::Readable for INTENSET_SPEC {
+    type Reader = R;
+}
+#[doc = "`write(|w| ..)` method takes [intenset::W](W) writer structure"]
+impl crate::Writable for INTENSET_SPEC {
+    type Writer = W;
+}
+#[doc = "`reset()` method sets INTENSET to value 0"]
+impl crate::Resettable for INTENSET_SPEC {
+    #[inline(always)]
+    fn reset_value() -> Self::Ux {
+        0
+    }
 }
