@@ -1,13 +1,37 @@
-#[doc = "Reader of register EPDATASTATUS"]
-pub type R = crate::R<u32, super::EPDATASTATUS>;
-#[doc = "Writer for register EPDATASTATUS"]
-pub type W = crate::W<u32, super::EPDATASTATUS>;
-#[doc = "Register EPDATASTATUS `reset()`'s with value 0"]
-impl crate::ResetValue for super::EPDATASTATUS {
-    type Type = u32;
+#[doc = "Register `EPDATASTATUS` reader"]
+pub struct R(crate::R<EPDATASTATUS_SPEC>);
+impl core::ops::Deref for R {
+    type Target = crate::R<EPDATASTATUS_SPEC>;
     #[inline(always)]
-    fn reset_value() -> Self::Type {
-        0
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+impl From<crate::R<EPDATASTATUS_SPEC>> for R {
+    #[inline(always)]
+    fn from(reader: crate::R<EPDATASTATUS_SPEC>) -> Self {
+        R(reader)
+    }
+}
+#[doc = "Register `EPDATASTATUS` writer"]
+pub struct W(crate::W<EPDATASTATUS_SPEC>);
+impl core::ops::Deref for W {
+    type Target = crate::W<EPDATASTATUS_SPEC>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+impl core::ops::DerefMut for W {
+    #[inline(always)]
+    fn deref_mut(&mut self) -> &mut Self::Target {
+        &mut self.0
+    }
+}
+impl From<crate::W<EPDATASTATUS_SPEC>> for W {
+    #[inline(always)]
+    fn from(writer: crate::W<EPDATASTATUS_SPEC>) -> Self {
+        W(writer)
     }
 }
 #[doc = "Acknowledged data transfer on this IN endpoint. Write '1' to clear.\n\nValue on reset: 0"]
@@ -24,9 +48,13 @@ impl From<EPIN1_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `EPIN1`"]
-pub type EPIN1_R = crate::R<bool, EPIN1_A>;
+#[doc = "Field `EPIN1` reader - Acknowledged data transfer on this IN endpoint. Write '1' to clear."]
+pub struct EPIN1_R(crate::FieldReader<bool, EPIN1_A>);
 impl EPIN1_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        EPIN1_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> EPIN1_A {
@@ -38,15 +66,22 @@ impl EPIN1_R {
     #[doc = "Checks if the value of the field is `NOTDONE`"]
     #[inline(always)]
     pub fn is_not_done(&self) -> bool {
-        *self == EPIN1_A::NOTDONE
+        **self == EPIN1_A::NOTDONE
     }
     #[doc = "Checks if the value of the field is `DATADONE`"]
     #[inline(always)]
     pub fn is_data_done(&self) -> bool {
-        *self == EPIN1_A::DATADONE
+        **self == EPIN1_A::DATADONE
     }
 }
-#[doc = "Write proxy for field `EPIN1`"]
+impl core::ops::Deref for EPIN1_R {
+    type Target = crate::FieldReader<bool, EPIN1_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EPIN1` writer - Acknowledged data transfer on this IN endpoint. Write '1' to clear."]
 pub struct EPIN1_W<'a> {
     w: &'a mut W,
 }
@@ -54,9 +89,7 @@ impl<'a> EPIN1_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: EPIN1_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "No acknowledged data transfer on this endpoint"]
     #[inline(always)]
@@ -81,7 +114,7 @@ impl<'a> EPIN1_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | (((value as u32) & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
         self.w
     }
 }
@@ -99,9 +132,13 @@ impl From<EPIN2_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `EPIN2`"]
-pub type EPIN2_R = crate::R<bool, EPIN2_A>;
+#[doc = "Field `EPIN2` reader - Acknowledged data transfer on this IN endpoint. Write '1' to clear."]
+pub struct EPIN2_R(crate::FieldReader<bool, EPIN2_A>);
 impl EPIN2_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        EPIN2_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> EPIN2_A {
@@ -113,15 +150,22 @@ impl EPIN2_R {
     #[doc = "Checks if the value of the field is `NOTDONE`"]
     #[inline(always)]
     pub fn is_not_done(&self) -> bool {
-        *self == EPIN2_A::NOTDONE
+        **self == EPIN2_A::NOTDONE
     }
     #[doc = "Checks if the value of the field is `DATADONE`"]
     #[inline(always)]
     pub fn is_data_done(&self) -> bool {
-        *self == EPIN2_A::DATADONE
+        **self == EPIN2_A::DATADONE
     }
 }
-#[doc = "Write proxy for field `EPIN2`"]
+impl core::ops::Deref for EPIN2_R {
+    type Target = crate::FieldReader<bool, EPIN2_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EPIN2` writer - Acknowledged data transfer on this IN endpoint. Write '1' to clear."]
 pub struct EPIN2_W<'a> {
     w: &'a mut W,
 }
@@ -129,9 +173,7 @@ impl<'a> EPIN2_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: EPIN2_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "No acknowledged data transfer on this endpoint"]
     #[inline(always)]
@@ -156,7 +198,7 @@ impl<'a> EPIN2_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | (((value as u32) & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
         self.w
     }
 }
@@ -174,9 +216,13 @@ impl From<EPIN3_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `EPIN3`"]
-pub type EPIN3_R = crate::R<bool, EPIN3_A>;
+#[doc = "Field `EPIN3` reader - Acknowledged data transfer on this IN endpoint. Write '1' to clear."]
+pub struct EPIN3_R(crate::FieldReader<bool, EPIN3_A>);
 impl EPIN3_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        EPIN3_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> EPIN3_A {
@@ -188,15 +234,22 @@ impl EPIN3_R {
     #[doc = "Checks if the value of the field is `NOTDONE`"]
     #[inline(always)]
     pub fn is_not_done(&self) -> bool {
-        *self == EPIN3_A::NOTDONE
+        **self == EPIN3_A::NOTDONE
     }
     #[doc = "Checks if the value of the field is `DATADONE`"]
     #[inline(always)]
     pub fn is_data_done(&self) -> bool {
-        *self == EPIN3_A::DATADONE
+        **self == EPIN3_A::DATADONE
     }
 }
-#[doc = "Write proxy for field `EPIN3`"]
+impl core::ops::Deref for EPIN3_R {
+    type Target = crate::FieldReader<bool, EPIN3_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EPIN3` writer - Acknowledged data transfer on this IN endpoint. Write '1' to clear."]
 pub struct EPIN3_W<'a> {
     w: &'a mut W,
 }
@@ -204,9 +257,7 @@ impl<'a> EPIN3_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: EPIN3_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "No acknowledged data transfer on this endpoint"]
     #[inline(always)]
@@ -231,7 +282,7 @@ impl<'a> EPIN3_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | (((value as u32) & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
         self.w
     }
 }
@@ -249,9 +300,13 @@ impl From<EPIN4_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `EPIN4`"]
-pub type EPIN4_R = crate::R<bool, EPIN4_A>;
+#[doc = "Field `EPIN4` reader - Acknowledged data transfer on this IN endpoint. Write '1' to clear."]
+pub struct EPIN4_R(crate::FieldReader<bool, EPIN4_A>);
 impl EPIN4_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        EPIN4_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> EPIN4_A {
@@ -263,15 +318,22 @@ impl EPIN4_R {
     #[doc = "Checks if the value of the field is `NOTDONE`"]
     #[inline(always)]
     pub fn is_not_done(&self) -> bool {
-        *self == EPIN4_A::NOTDONE
+        **self == EPIN4_A::NOTDONE
     }
     #[doc = "Checks if the value of the field is `DATADONE`"]
     #[inline(always)]
     pub fn is_data_done(&self) -> bool {
-        *self == EPIN4_A::DATADONE
+        **self == EPIN4_A::DATADONE
     }
 }
-#[doc = "Write proxy for field `EPIN4`"]
+impl core::ops::Deref for EPIN4_R {
+    type Target = crate::FieldReader<bool, EPIN4_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EPIN4` writer - Acknowledged data transfer on this IN endpoint. Write '1' to clear."]
 pub struct EPIN4_W<'a> {
     w: &'a mut W,
 }
@@ -279,9 +341,7 @@ impl<'a> EPIN4_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: EPIN4_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "No acknowledged data transfer on this endpoint"]
     #[inline(always)]
@@ -306,7 +366,7 @@ impl<'a> EPIN4_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | (((value as u32) & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
         self.w
     }
 }
@@ -324,9 +384,13 @@ impl From<EPIN5_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `EPIN5`"]
-pub type EPIN5_R = crate::R<bool, EPIN5_A>;
+#[doc = "Field `EPIN5` reader - Acknowledged data transfer on this IN endpoint. Write '1' to clear."]
+pub struct EPIN5_R(crate::FieldReader<bool, EPIN5_A>);
 impl EPIN5_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        EPIN5_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> EPIN5_A {
@@ -338,15 +402,22 @@ impl EPIN5_R {
     #[doc = "Checks if the value of the field is `NOTDONE`"]
     #[inline(always)]
     pub fn is_not_done(&self) -> bool {
-        *self == EPIN5_A::NOTDONE
+        **self == EPIN5_A::NOTDONE
     }
     #[doc = "Checks if the value of the field is `DATADONE`"]
     #[inline(always)]
     pub fn is_data_done(&self) -> bool {
-        *self == EPIN5_A::DATADONE
+        **self == EPIN5_A::DATADONE
     }
 }
-#[doc = "Write proxy for field `EPIN5`"]
+impl core::ops::Deref for EPIN5_R {
+    type Target = crate::FieldReader<bool, EPIN5_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EPIN5` writer - Acknowledged data transfer on this IN endpoint. Write '1' to clear."]
 pub struct EPIN5_W<'a> {
     w: &'a mut W,
 }
@@ -354,9 +425,7 @@ impl<'a> EPIN5_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: EPIN5_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "No acknowledged data transfer on this endpoint"]
     #[inline(always)]
@@ -381,7 +450,7 @@ impl<'a> EPIN5_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | (((value as u32) & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
         self.w
     }
 }
@@ -399,9 +468,13 @@ impl From<EPIN6_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `EPIN6`"]
-pub type EPIN6_R = crate::R<bool, EPIN6_A>;
+#[doc = "Field `EPIN6` reader - Acknowledged data transfer on this IN endpoint. Write '1' to clear."]
+pub struct EPIN6_R(crate::FieldReader<bool, EPIN6_A>);
 impl EPIN6_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        EPIN6_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> EPIN6_A {
@@ -413,15 +486,22 @@ impl EPIN6_R {
     #[doc = "Checks if the value of the field is `NOTDONE`"]
     #[inline(always)]
     pub fn is_not_done(&self) -> bool {
-        *self == EPIN6_A::NOTDONE
+        **self == EPIN6_A::NOTDONE
     }
     #[doc = "Checks if the value of the field is `DATADONE`"]
     #[inline(always)]
     pub fn is_data_done(&self) -> bool {
-        *self == EPIN6_A::DATADONE
+        **self == EPIN6_A::DATADONE
     }
 }
-#[doc = "Write proxy for field `EPIN6`"]
+impl core::ops::Deref for EPIN6_R {
+    type Target = crate::FieldReader<bool, EPIN6_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EPIN6` writer - Acknowledged data transfer on this IN endpoint. Write '1' to clear."]
 pub struct EPIN6_W<'a> {
     w: &'a mut W,
 }
@@ -429,9 +509,7 @@ impl<'a> EPIN6_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: EPIN6_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "No acknowledged data transfer on this endpoint"]
     #[inline(always)]
@@ -456,7 +534,7 @@ impl<'a> EPIN6_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | (((value as u32) & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
         self.w
     }
 }
@@ -474,9 +552,13 @@ impl From<EPIN7_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `EPIN7`"]
-pub type EPIN7_R = crate::R<bool, EPIN7_A>;
+#[doc = "Field `EPIN7` reader - Acknowledged data transfer on this IN endpoint. Write '1' to clear."]
+pub struct EPIN7_R(crate::FieldReader<bool, EPIN7_A>);
 impl EPIN7_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        EPIN7_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> EPIN7_A {
@@ -488,15 +570,22 @@ impl EPIN7_R {
     #[doc = "Checks if the value of the field is `NOTDONE`"]
     #[inline(always)]
     pub fn is_not_done(&self) -> bool {
-        *self == EPIN7_A::NOTDONE
+        **self == EPIN7_A::NOTDONE
     }
     #[doc = "Checks if the value of the field is `DATADONE`"]
     #[inline(always)]
     pub fn is_data_done(&self) -> bool {
-        *self == EPIN7_A::DATADONE
+        **self == EPIN7_A::DATADONE
     }
 }
-#[doc = "Write proxy for field `EPIN7`"]
+impl core::ops::Deref for EPIN7_R {
+    type Target = crate::FieldReader<bool, EPIN7_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EPIN7` writer - Acknowledged data transfer on this IN endpoint. Write '1' to clear."]
 pub struct EPIN7_W<'a> {
     w: &'a mut W,
 }
@@ -504,9 +593,7 @@ impl<'a> EPIN7_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: EPIN7_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "No acknowledged data transfer on this endpoint"]
     #[inline(always)]
@@ -531,7 +618,7 @@ impl<'a> EPIN7_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | (((value as u32) & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
         self.w
     }
 }
@@ -549,9 +636,13 @@ impl From<EPOUT1_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `EPOUT1`"]
-pub type EPOUT1_R = crate::R<bool, EPOUT1_A>;
+#[doc = "Field `EPOUT1` reader - Acknowledged data transfer on this OUT endpoint. Write '1' to clear."]
+pub struct EPOUT1_R(crate::FieldReader<bool, EPOUT1_A>);
 impl EPOUT1_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        EPOUT1_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> EPOUT1_A {
@@ -563,15 +654,22 @@ impl EPOUT1_R {
     #[doc = "Checks if the value of the field is `NOTSTARTED`"]
     #[inline(always)]
     pub fn is_not_started(&self) -> bool {
-        *self == EPOUT1_A::NOTSTARTED
+        **self == EPOUT1_A::NOTSTARTED
     }
     #[doc = "Checks if the value of the field is `STARTED`"]
     #[inline(always)]
     pub fn is_started(&self) -> bool {
-        *self == EPOUT1_A::STARTED
+        **self == EPOUT1_A::STARTED
     }
 }
-#[doc = "Write proxy for field `EPOUT1`"]
+impl core::ops::Deref for EPOUT1_R {
+    type Target = crate::FieldReader<bool, EPOUT1_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EPOUT1` writer - Acknowledged data transfer on this OUT endpoint. Write '1' to clear."]
 pub struct EPOUT1_W<'a> {
     w: &'a mut W,
 }
@@ -579,9 +677,7 @@ impl<'a> EPOUT1_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: EPOUT1_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "No acknowledged data transfer on this endpoint"]
     #[inline(always)]
@@ -606,7 +702,7 @@ impl<'a> EPOUT1_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 17)) | (((value as u32) & 0x01) << 17);
+        self.w.bits = (self.w.bits & !(0x01 << 17)) | ((value as u32 & 0x01) << 17);
         self.w
     }
 }
@@ -624,9 +720,13 @@ impl From<EPOUT2_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `EPOUT2`"]
-pub type EPOUT2_R = crate::R<bool, EPOUT2_A>;
+#[doc = "Field `EPOUT2` reader - Acknowledged data transfer on this OUT endpoint. Write '1' to clear."]
+pub struct EPOUT2_R(crate::FieldReader<bool, EPOUT2_A>);
 impl EPOUT2_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        EPOUT2_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> EPOUT2_A {
@@ -638,15 +738,22 @@ impl EPOUT2_R {
     #[doc = "Checks if the value of the field is `NOTSTARTED`"]
     #[inline(always)]
     pub fn is_not_started(&self) -> bool {
-        *self == EPOUT2_A::NOTSTARTED
+        **self == EPOUT2_A::NOTSTARTED
     }
     #[doc = "Checks if the value of the field is `STARTED`"]
     #[inline(always)]
     pub fn is_started(&self) -> bool {
-        *self == EPOUT2_A::STARTED
+        **self == EPOUT2_A::STARTED
     }
 }
-#[doc = "Write proxy for field `EPOUT2`"]
+impl core::ops::Deref for EPOUT2_R {
+    type Target = crate::FieldReader<bool, EPOUT2_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EPOUT2` writer - Acknowledged data transfer on this OUT endpoint. Write '1' to clear."]
 pub struct EPOUT2_W<'a> {
     w: &'a mut W,
 }
@@ -654,9 +761,7 @@ impl<'a> EPOUT2_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: EPOUT2_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "No acknowledged data transfer on this endpoint"]
     #[inline(always)]
@@ -681,7 +786,7 @@ impl<'a> EPOUT2_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 18)) | (((value as u32) & 0x01) << 18);
+        self.w.bits = (self.w.bits & !(0x01 << 18)) | ((value as u32 & 0x01) << 18);
         self.w
     }
 }
@@ -699,9 +804,13 @@ impl From<EPOUT3_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `EPOUT3`"]
-pub type EPOUT3_R = crate::R<bool, EPOUT3_A>;
+#[doc = "Field `EPOUT3` reader - Acknowledged data transfer on this OUT endpoint. Write '1' to clear."]
+pub struct EPOUT3_R(crate::FieldReader<bool, EPOUT3_A>);
 impl EPOUT3_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        EPOUT3_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> EPOUT3_A {
@@ -713,15 +822,22 @@ impl EPOUT3_R {
     #[doc = "Checks if the value of the field is `NOTSTARTED`"]
     #[inline(always)]
     pub fn is_not_started(&self) -> bool {
-        *self == EPOUT3_A::NOTSTARTED
+        **self == EPOUT3_A::NOTSTARTED
     }
     #[doc = "Checks if the value of the field is `STARTED`"]
     #[inline(always)]
     pub fn is_started(&self) -> bool {
-        *self == EPOUT3_A::STARTED
+        **self == EPOUT3_A::STARTED
     }
 }
-#[doc = "Write proxy for field `EPOUT3`"]
+impl core::ops::Deref for EPOUT3_R {
+    type Target = crate::FieldReader<bool, EPOUT3_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EPOUT3` writer - Acknowledged data transfer on this OUT endpoint. Write '1' to clear."]
 pub struct EPOUT3_W<'a> {
     w: &'a mut W,
 }
@@ -729,9 +845,7 @@ impl<'a> EPOUT3_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: EPOUT3_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "No acknowledged data transfer on this endpoint"]
     #[inline(always)]
@@ -756,7 +870,7 @@ impl<'a> EPOUT3_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 19)) | (((value as u32) & 0x01) << 19);
+        self.w.bits = (self.w.bits & !(0x01 << 19)) | ((value as u32 & 0x01) << 19);
         self.w
     }
 }
@@ -774,9 +888,13 @@ impl From<EPOUT4_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `EPOUT4`"]
-pub type EPOUT4_R = crate::R<bool, EPOUT4_A>;
+#[doc = "Field `EPOUT4` reader - Acknowledged data transfer on this OUT endpoint. Write '1' to clear."]
+pub struct EPOUT4_R(crate::FieldReader<bool, EPOUT4_A>);
 impl EPOUT4_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        EPOUT4_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> EPOUT4_A {
@@ -788,15 +906,22 @@ impl EPOUT4_R {
     #[doc = "Checks if the value of the field is `NOTSTARTED`"]
     #[inline(always)]
     pub fn is_not_started(&self) -> bool {
-        *self == EPOUT4_A::NOTSTARTED
+        **self == EPOUT4_A::NOTSTARTED
     }
     #[doc = "Checks if the value of the field is `STARTED`"]
     #[inline(always)]
     pub fn is_started(&self) -> bool {
-        *self == EPOUT4_A::STARTED
+        **self == EPOUT4_A::STARTED
     }
 }
-#[doc = "Write proxy for field `EPOUT4`"]
+impl core::ops::Deref for EPOUT4_R {
+    type Target = crate::FieldReader<bool, EPOUT4_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EPOUT4` writer - Acknowledged data transfer on this OUT endpoint. Write '1' to clear."]
 pub struct EPOUT4_W<'a> {
     w: &'a mut W,
 }
@@ -804,9 +929,7 @@ impl<'a> EPOUT4_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: EPOUT4_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "No acknowledged data transfer on this endpoint"]
     #[inline(always)]
@@ -831,7 +954,7 @@ impl<'a> EPOUT4_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 20)) | (((value as u32) & 0x01) << 20);
+        self.w.bits = (self.w.bits & !(0x01 << 20)) | ((value as u32 & 0x01) << 20);
         self.w
     }
 }
@@ -849,9 +972,13 @@ impl From<EPOUT5_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `EPOUT5`"]
-pub type EPOUT5_R = crate::R<bool, EPOUT5_A>;
+#[doc = "Field `EPOUT5` reader - Acknowledged data transfer on this OUT endpoint. Write '1' to clear."]
+pub struct EPOUT5_R(crate::FieldReader<bool, EPOUT5_A>);
 impl EPOUT5_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        EPOUT5_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> EPOUT5_A {
@@ -863,15 +990,22 @@ impl EPOUT5_R {
     #[doc = "Checks if the value of the field is `NOTSTARTED`"]
     #[inline(always)]
     pub fn is_not_started(&self) -> bool {
-        *self == EPOUT5_A::NOTSTARTED
+        **self == EPOUT5_A::NOTSTARTED
     }
     #[doc = "Checks if the value of the field is `STARTED`"]
     #[inline(always)]
     pub fn is_started(&self) -> bool {
-        *self == EPOUT5_A::STARTED
+        **self == EPOUT5_A::STARTED
     }
 }
-#[doc = "Write proxy for field `EPOUT5`"]
+impl core::ops::Deref for EPOUT5_R {
+    type Target = crate::FieldReader<bool, EPOUT5_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EPOUT5` writer - Acknowledged data transfer on this OUT endpoint. Write '1' to clear."]
 pub struct EPOUT5_W<'a> {
     w: &'a mut W,
 }
@@ -879,9 +1013,7 @@ impl<'a> EPOUT5_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: EPOUT5_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "No acknowledged data transfer on this endpoint"]
     #[inline(always)]
@@ -906,7 +1038,7 @@ impl<'a> EPOUT5_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 21)) | (((value as u32) & 0x01) << 21);
+        self.w.bits = (self.w.bits & !(0x01 << 21)) | ((value as u32 & 0x01) << 21);
         self.w
     }
 }
@@ -924,9 +1056,13 @@ impl From<EPOUT6_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `EPOUT6`"]
-pub type EPOUT6_R = crate::R<bool, EPOUT6_A>;
+#[doc = "Field `EPOUT6` reader - Acknowledged data transfer on this OUT endpoint. Write '1' to clear."]
+pub struct EPOUT6_R(crate::FieldReader<bool, EPOUT6_A>);
 impl EPOUT6_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        EPOUT6_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> EPOUT6_A {
@@ -938,15 +1074,22 @@ impl EPOUT6_R {
     #[doc = "Checks if the value of the field is `NOTSTARTED`"]
     #[inline(always)]
     pub fn is_not_started(&self) -> bool {
-        *self == EPOUT6_A::NOTSTARTED
+        **self == EPOUT6_A::NOTSTARTED
     }
     #[doc = "Checks if the value of the field is `STARTED`"]
     #[inline(always)]
     pub fn is_started(&self) -> bool {
-        *self == EPOUT6_A::STARTED
+        **self == EPOUT6_A::STARTED
     }
 }
-#[doc = "Write proxy for field `EPOUT6`"]
+impl core::ops::Deref for EPOUT6_R {
+    type Target = crate::FieldReader<bool, EPOUT6_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EPOUT6` writer - Acknowledged data transfer on this OUT endpoint. Write '1' to clear."]
 pub struct EPOUT6_W<'a> {
     w: &'a mut W,
 }
@@ -954,9 +1097,7 @@ impl<'a> EPOUT6_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: EPOUT6_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "No acknowledged data transfer on this endpoint"]
     #[inline(always)]
@@ -981,7 +1122,7 @@ impl<'a> EPOUT6_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 22)) | (((value as u32) & 0x01) << 22);
+        self.w.bits = (self.w.bits & !(0x01 << 22)) | ((value as u32 & 0x01) << 22);
         self.w
     }
 }
@@ -999,9 +1140,13 @@ impl From<EPOUT7_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `EPOUT7`"]
-pub type EPOUT7_R = crate::R<bool, EPOUT7_A>;
+#[doc = "Field `EPOUT7` reader - Acknowledged data transfer on this OUT endpoint. Write '1' to clear."]
+pub struct EPOUT7_R(crate::FieldReader<bool, EPOUT7_A>);
 impl EPOUT7_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        EPOUT7_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> EPOUT7_A {
@@ -1013,15 +1158,22 @@ impl EPOUT7_R {
     #[doc = "Checks if the value of the field is `NOTSTARTED`"]
     #[inline(always)]
     pub fn is_not_started(&self) -> bool {
-        *self == EPOUT7_A::NOTSTARTED
+        **self == EPOUT7_A::NOTSTARTED
     }
     #[doc = "Checks if the value of the field is `STARTED`"]
     #[inline(always)]
     pub fn is_started(&self) -> bool {
-        *self == EPOUT7_A::STARTED
+        **self == EPOUT7_A::STARTED
     }
 }
-#[doc = "Write proxy for field `EPOUT7`"]
+impl core::ops::Deref for EPOUT7_R {
+    type Target = crate::FieldReader<bool, EPOUT7_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `EPOUT7` writer - Acknowledged data transfer on this OUT endpoint. Write '1' to clear."]
 pub struct EPOUT7_W<'a> {
     w: &'a mut W,
 }
@@ -1029,9 +1181,7 @@ impl<'a> EPOUT7_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: EPOUT7_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "No acknowledged data transfer on this endpoint"]
     #[inline(always)]
@@ -1056,7 +1206,7 @@ impl<'a> EPOUT7_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 23)) | (((value as u32) & 0x01) << 23);
+        self.w.bits = (self.w.bits & !(0x01 << 23)) | ((value as u32 & 0x01) << 23);
         self.w
     }
 }
@@ -1203,4 +1353,30 @@ impl W {
     pub fn epout7(&mut self) -> EPOUT7_W {
         EPOUT7_W { w: self }
     }
+    #[doc = "Writes raw bits to the register."]
+    #[inline(always)]
+    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
+        self.0.bits(bits);
+        self
+    }
+}
+#[doc = "Provides information on which endpoint(s) an acknowledged data transfer has occurred (EPDATA event)\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [epdatastatus](index.html) module"]
+pub struct EPDATASTATUS_SPEC;
+impl crate::RegisterSpec for EPDATASTATUS_SPEC {
+    type Ux = u32;
+}
+#[doc = "`read()` method returns [epdatastatus::R](R) reader structure"]
+impl crate::Readable for EPDATASTATUS_SPEC {
+    type Reader = R;
+}
+#[doc = "`write(|w| ..)` method takes [epdatastatus::W](W) writer structure"]
+impl crate::Writable for EPDATASTATUS_SPEC {
+    type Writer = W;
+}
+#[doc = "`reset()` method sets EPDATASTATUS to value 0"]
+impl crate::Resettable for EPDATASTATUS_SPEC {
+    #[inline(always)]
+    fn reset_value() -> Self::Ux {
+        0
+    }
 }
