@@ -1,13 +1,37 @@
-#[doc = "Reader of register EPINEN"]
-pub type R = crate::R<u32, super::EPINEN>;
-#[doc = "Writer for register EPINEN"]
-pub type W = crate::W<u32, super::EPINEN>;
-#[doc = "Register EPINEN `reset()`'s with value 0x01"]
-impl crate::ResetValue for super::EPINEN {
-    type Type = u32;
+#[doc = "Register `EPINEN` reader"]
+pub struct R(crate::R<EPINEN_SPEC>);
+impl core::ops::Deref for R {
+    type Target = crate::R<EPINEN_SPEC>;
     #[inline(always)]
-    fn reset_value() -> Self::Type {
-        0x01
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+impl From<crate::R<EPINEN_SPEC>> for R {
+    #[inline(always)]
+    fn from(reader: crate::R<EPINEN_SPEC>) -> Self {
+        R(reader)
+    }
+}
+#[doc = "Register `EPINEN` writer"]
+pub struct W(crate::W<EPINEN_SPEC>);
+impl core::ops::Deref for W {
+    type Target = crate::W<EPINEN_SPEC>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+impl core::ops::DerefMut for W {
+    #[inline(always)]
+    fn deref_mut(&mut self) -> &mut Self::Target {
+        &mut self.0
+    }
+}
+impl From<crate::W<EPINEN_SPEC>> for W {
+    #[inline(always)]
+    fn from(writer: crate::W<EPINEN_SPEC>) -> Self {
+        W(writer)
     }
 }
 #[doc = "Enable IN endpoint 0\n\nValue on reset: 1"]
@@ -24,9 +48,13 @@ impl From<IN0_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `IN0`"]
-pub type IN0_R = crate::R<bool, IN0_A>;
+#[doc = "Field `IN0` reader - Enable IN endpoint 0"]
+pub struct IN0_R(crate::FieldReader<bool, IN0_A>);
 impl IN0_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        IN0_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> IN0_A {
@@ -38,15 +66,22 @@ impl IN0_R {
     #[doc = "Checks if the value of the field is `DISABLE`"]
     #[inline(always)]
     pub fn is_disable(&self) -> bool {
-        *self == IN0_A::DISABLE
+        **self == IN0_A::DISABLE
     }
     #[doc = "Checks if the value of the field is `ENABLE`"]
     #[inline(always)]
     pub fn is_enable(&self) -> bool {
-        *self == IN0_A::ENABLE
+        **self == IN0_A::ENABLE
     }
 }
-#[doc = "Write proxy for field `IN0`"]
+impl core::ops::Deref for IN0_R {
+    type Target = crate::FieldReader<bool, IN0_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `IN0` writer - Enable IN endpoint 0"]
 pub struct IN0_W<'a> {
     w: &'a mut W,
 }
@@ -54,9 +89,7 @@ impl<'a> IN0_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: IN0_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Disable endpoint IN 0 (no response to IN tokens)"]
     #[inline(always)]
@@ -81,7 +114,7 @@ impl<'a> IN0_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !0x01) | ((value as u32) & 0x01);
+        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
         self.w
     }
 }
@@ -99,9 +132,13 @@ impl From<IN1_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `IN1`"]
-pub type IN1_R = crate::R<bool, IN1_A>;
+#[doc = "Field `IN1` reader - Enable IN endpoint 1"]
+pub struct IN1_R(crate::FieldReader<bool, IN1_A>);
 impl IN1_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        IN1_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> IN1_A {
@@ -113,15 +150,22 @@ impl IN1_R {
     #[doc = "Checks if the value of the field is `DISABLE`"]
     #[inline(always)]
     pub fn is_disable(&self) -> bool {
-        *self == IN1_A::DISABLE
+        **self == IN1_A::DISABLE
     }
     #[doc = "Checks if the value of the field is `ENABLE`"]
     #[inline(always)]
     pub fn is_enable(&self) -> bool {
-        *self == IN1_A::ENABLE
+        **self == IN1_A::ENABLE
     }
 }
-#[doc = "Write proxy for field `IN1`"]
+impl core::ops::Deref for IN1_R {
+    type Target = crate::FieldReader<bool, IN1_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `IN1` writer - Enable IN endpoint 1"]
 pub struct IN1_W<'a> {
     w: &'a mut W,
 }
@@ -129,9 +173,7 @@ impl<'a> IN1_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: IN1_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Disable endpoint IN 1 (no response to IN tokens)"]
     #[inline(always)]
@@ -156,7 +198,7 @@ impl<'a> IN1_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 1)) | (((value as u32) & 0x01) << 1);
+        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
         self.w
     }
 }
@@ -174,9 +216,13 @@ impl From<IN2_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `IN2`"]
-pub type IN2_R = crate::R<bool, IN2_A>;
+#[doc = "Field `IN2` reader - Enable IN endpoint 2"]
+pub struct IN2_R(crate::FieldReader<bool, IN2_A>);
 impl IN2_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        IN2_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> IN2_A {
@@ -188,15 +234,22 @@ impl IN2_R {
     #[doc = "Checks if the value of the field is `DISABLE`"]
     #[inline(always)]
     pub fn is_disable(&self) -> bool {
-        *self == IN2_A::DISABLE
+        **self == IN2_A::DISABLE
     }
     #[doc = "Checks if the value of the field is `ENABLE`"]
     #[inline(always)]
     pub fn is_enable(&self) -> bool {
-        *self == IN2_A::ENABLE
+        **self == IN2_A::ENABLE
     }
 }
-#[doc = "Write proxy for field `IN2`"]
+impl core::ops::Deref for IN2_R {
+    type Target = crate::FieldReader<bool, IN2_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `IN2` writer - Enable IN endpoint 2"]
 pub struct IN2_W<'a> {
     w: &'a mut W,
 }
@@ -204,9 +257,7 @@ impl<'a> IN2_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: IN2_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Disable endpoint IN 2 (no response to IN tokens)"]
     #[inline(always)]
@@ -231,7 +282,7 @@ impl<'a> IN2_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 2)) | (((value as u32) & 0x01) << 2);
+        self.w.bits = (self.w.bits & !(0x01 << 2)) | ((value as u32 & 0x01) << 2);
         self.w
     }
 }
@@ -249,9 +300,13 @@ impl From<IN3_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `IN3`"]
-pub type IN3_R = crate::R<bool, IN3_A>;
+#[doc = "Field `IN3` reader - Enable IN endpoint 3"]
+pub struct IN3_R(crate::FieldReader<bool, IN3_A>);
 impl IN3_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        IN3_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> IN3_A {
@@ -263,15 +318,22 @@ impl IN3_R {
     #[doc = "Checks if the value of the field is `DISABLE`"]
     #[inline(always)]
     pub fn is_disable(&self) -> bool {
-        *self == IN3_A::DISABLE
+        **self == IN3_A::DISABLE
     }
     #[doc = "Checks if the value of the field is `ENABLE`"]
     #[inline(always)]
     pub fn is_enable(&self) -> bool {
-        *self == IN3_A::ENABLE
+        **self == IN3_A::ENABLE
     }
 }
-#[doc = "Write proxy for field `IN3`"]
+impl core::ops::Deref for IN3_R {
+    type Target = crate::FieldReader<bool, IN3_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `IN3` writer - Enable IN endpoint 3"]
 pub struct IN3_W<'a> {
     w: &'a mut W,
 }
@@ -279,9 +341,7 @@ impl<'a> IN3_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: IN3_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Disable endpoint IN 3 (no response to IN tokens)"]
     #[inline(always)]
@@ -306,7 +366,7 @@ impl<'a> IN3_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 3)) | (((value as u32) & 0x01) << 3);
+        self.w.bits = (self.w.bits & !(0x01 << 3)) | ((value as u32 & 0x01) << 3);
         self.w
     }
 }
@@ -324,9 +384,13 @@ impl From<IN4_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `IN4`"]
-pub type IN4_R = crate::R<bool, IN4_A>;
+#[doc = "Field `IN4` reader - Enable IN endpoint 4"]
+pub struct IN4_R(crate::FieldReader<bool, IN4_A>);
 impl IN4_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        IN4_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> IN4_A {
@@ -338,15 +402,22 @@ impl IN4_R {
     #[doc = "Checks if the value of the field is `DISABLE`"]
     #[inline(always)]
     pub fn is_disable(&self) -> bool {
-        *self == IN4_A::DISABLE
+        **self == IN4_A::DISABLE
     }
     #[doc = "Checks if the value of the field is `ENABLE`"]
     #[inline(always)]
     pub fn is_enable(&self) -> bool {
-        *self == IN4_A::ENABLE
+        **self == IN4_A::ENABLE
     }
 }
-#[doc = "Write proxy for field `IN4`"]
+impl core::ops::Deref for IN4_R {
+    type Target = crate::FieldReader<bool, IN4_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `IN4` writer - Enable IN endpoint 4"]
 pub struct IN4_W<'a> {
     w: &'a mut W,
 }
@@ -354,9 +425,7 @@ impl<'a> IN4_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: IN4_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Disable endpoint IN 4 (no response to IN tokens)"]
     #[inline(always)]
@@ -381,7 +450,7 @@ impl<'a> IN4_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 4)) | (((value as u32) & 0x01) << 4);
+        self.w.bits = (self.w.bits & !(0x01 << 4)) | ((value as u32 & 0x01) << 4);
         self.w
     }
 }
@@ -399,9 +468,13 @@ impl From<IN5_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `IN5`"]
-pub type IN5_R = crate::R<bool, IN5_A>;
+#[doc = "Field `IN5` reader - Enable IN endpoint 5"]
+pub struct IN5_R(crate::FieldReader<bool, IN5_A>);
 impl IN5_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        IN5_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> IN5_A {
@@ -413,15 +486,22 @@ impl IN5_R {
     #[doc = "Checks if the value of the field is `DISABLE`"]
     #[inline(always)]
     pub fn is_disable(&self) -> bool {
-        *self == IN5_A::DISABLE
+        **self == IN5_A::DISABLE
     }
     #[doc = "Checks if the value of the field is `ENABLE`"]
     #[inline(always)]
     pub fn is_enable(&self) -> bool {
-        *self == IN5_A::ENABLE
+        **self == IN5_A::ENABLE
     }
 }
-#[doc = "Write proxy for field `IN5`"]
+impl core::ops::Deref for IN5_R {
+    type Target = crate::FieldReader<bool, IN5_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `IN5` writer - Enable IN endpoint 5"]
 pub struct IN5_W<'a> {
     w: &'a mut W,
 }
@@ -429,9 +509,7 @@ impl<'a> IN5_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: IN5_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Disable endpoint IN 5 (no response to IN tokens)"]
     #[inline(always)]
@@ -456,7 +534,7 @@ impl<'a> IN5_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 5)) | (((value as u32) & 0x01) << 5);
+        self.w.bits = (self.w.bits & !(0x01 << 5)) | ((value as u32 & 0x01) << 5);
         self.w
     }
 }
@@ -474,9 +552,13 @@ impl From<IN6_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `IN6`"]
-pub type IN6_R = crate::R<bool, IN6_A>;
+#[doc = "Field `IN6` reader - Enable IN endpoint 6"]
+pub struct IN6_R(crate::FieldReader<bool, IN6_A>);
 impl IN6_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        IN6_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> IN6_A {
@@ -488,15 +570,22 @@ impl IN6_R {
     #[doc = "Checks if the value of the field is `DISABLE`"]
     #[inline(always)]
     pub fn is_disable(&self) -> bool {
-        *self == IN6_A::DISABLE
+        **self == IN6_A::DISABLE
     }
     #[doc = "Checks if the value of the field is `ENABLE`"]
     #[inline(always)]
     pub fn is_enable(&self) -> bool {
-        *self == IN6_A::ENABLE
+        **self == IN6_A::ENABLE
     }
 }
-#[doc = "Write proxy for field `IN6`"]
+impl core::ops::Deref for IN6_R {
+    type Target = crate::FieldReader<bool, IN6_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `IN6` writer - Enable IN endpoint 6"]
 pub struct IN6_W<'a> {
     w: &'a mut W,
 }
@@ -504,9 +593,7 @@ impl<'a> IN6_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: IN6_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Disable endpoint IN 6 (no response to IN tokens)"]
     #[inline(always)]
@@ -531,7 +618,7 @@ impl<'a> IN6_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 6)) | (((value as u32) & 0x01) << 6);
+        self.w.bits = (self.w.bits & !(0x01 << 6)) | ((value as u32 & 0x01) << 6);
         self.w
     }
 }
@@ -549,9 +636,13 @@ impl From<IN7_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `IN7`"]
-pub type IN7_R = crate::R<bool, IN7_A>;
+#[doc = "Field `IN7` reader - Enable IN endpoint 7"]
+pub struct IN7_R(crate::FieldReader<bool, IN7_A>);
 impl IN7_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        IN7_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> IN7_A {
@@ -563,15 +654,22 @@ impl IN7_R {
     #[doc = "Checks if the value of the field is `DISABLE`"]
     #[inline(always)]
     pub fn is_disable(&self) -> bool {
-        *self == IN7_A::DISABLE
+        **self == IN7_A::DISABLE
     }
     #[doc = "Checks if the value of the field is `ENABLE`"]
     #[inline(always)]
     pub fn is_enable(&self) -> bool {
-        *self == IN7_A::ENABLE
+        **self == IN7_A::ENABLE
     }
 }
-#[doc = "Write proxy for field `IN7`"]
+impl core::ops::Deref for IN7_R {
+    type Target = crate::FieldReader<bool, IN7_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `IN7` writer - Enable IN endpoint 7"]
 pub struct IN7_W<'a> {
     w: &'a mut W,
 }
@@ -579,9 +677,7 @@ impl<'a> IN7_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: IN7_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Disable endpoint IN 7 (no response to IN tokens)"]
     #[inline(always)]
@@ -606,7 +702,7 @@ impl<'a> IN7_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 7)) | (((value as u32) & 0x01) << 7);
+        self.w.bits = (self.w.bits & !(0x01 << 7)) | ((value as u32 & 0x01) << 7);
         self.w
     }
 }
@@ -624,9 +720,13 @@ impl From<ISOIN_A> for bool {
         variant as u8 != 0
     }
 }
-#[doc = "Reader of field `ISOIN`"]
-pub type ISOIN_R = crate::R<bool, ISOIN_A>;
+#[doc = "Field `ISOIN` reader - Enable ISO IN endpoint"]
+pub struct ISOIN_R(crate::FieldReader<bool, ISOIN_A>);
 impl ISOIN_R {
+    #[inline(always)]
+    pub(crate) fn new(bits: bool) -> Self {
+        ISOIN_R(crate::FieldReader::new(bits))
+    }
     #[doc = r"Get enumerated values variant"]
     #[inline(always)]
     pub fn variant(&self) -> ISOIN_A {
@@ -638,15 +738,22 @@ impl ISOIN_R {
     #[doc = "Checks if the value of the field is `DISABLE`"]
     #[inline(always)]
     pub fn is_disable(&self) -> bool {
-        *self == ISOIN_A::DISABLE
+        **self == ISOIN_A::DISABLE
     }
     #[doc = "Checks if the value of the field is `ENABLE`"]
     #[inline(always)]
     pub fn is_enable(&self) -> bool {
-        *self == ISOIN_A::ENABLE
+        **self == ISOIN_A::ENABLE
     }
 }
-#[doc = "Write proxy for field `ISOIN`"]
+impl core::ops::Deref for ISOIN_R {
+    type Target = crate::FieldReader<bool, ISOIN_A>;
+    #[inline(always)]
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
+#[doc = "Field `ISOIN` writer - Enable ISO IN endpoint"]
 pub struct ISOIN_W<'a> {
     w: &'a mut W,
 }
@@ -654,9 +761,7 @@ impl<'a> ISOIN_W<'a> {
     #[doc = r"Writes `variant` to the field"]
     #[inline(always)]
     pub fn variant(self, variant: ISOIN_A) -> &'a mut W {
-        {
-            self.bit(variant.into())
-        }
+        self.bit(variant.into())
     }
     #[doc = "Disable ISO IN endpoint 8"]
     #[inline(always)]
@@ -681,7 +786,7 @@ impl<'a> ISOIN_W<'a> {
     #[doc = r"Writes raw bits to the field"]
     #[inline(always)]
     pub fn bit(self, value: bool) -> &'a mut W {
-        self.w.bits = (self.w.bits & !(0x01 << 8)) | (((value as u32) & 0x01) << 8);
+        self.w.bits = (self.w.bits & !(0x01 << 8)) | ((value as u32 & 0x01) << 8);
         self.w
     }
 }
@@ -778,4 +883,30 @@ impl W {
     pub fn isoin(&mut self) -> ISOIN_W {
         ISOIN_W { w: self }
     }
+    #[doc = "Writes raw bits to the register."]
+    #[inline(always)]
+    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
+        self.0.bits(bits);
+        self
+    }
+}
+#[doc = "Endpoint IN enable\n\nThis register you can [`read`](crate::generic::Reg::read), [`write_with_zero`](crate::generic::Reg::write_with_zero), [`reset`](crate::generic::Reg::reset), [`write`](crate::generic::Reg::write), [`modify`](crate::generic::Reg::modify). See [API](https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [epinen](index.html) module"]
+pub struct EPINEN_SPEC;
+impl crate::RegisterSpec for EPINEN_SPEC {
+    type Ux = u32;
+}
+#[doc = "`read()` method returns [epinen::R](R) reader structure"]
+impl crate::Readable for EPINEN_SPEC {
+    type Reader = R;
+}
+#[doc = "`write(|w| ..)` method takes [epinen::W](W) writer structure"]
+impl crate::Writable for EPINEN_SPEC {
+    type Writer = W;
+}
+#[doc = "`reset()` method sets EPINEN to value 0x01"]
+impl crate::Resettable for EPINEN_SPEC {
+    #[inline(always)]
+    fn reset_value() -> Self::Ux {
+        0x01
+    }
 }
